@@ -12,17 +12,20 @@ class CoingeckoService:
         self.base_url = "https://api.coingecko.com/api/v3"
         self.rest_client = rest_client
         self.limiter = Limiter(1000, 1)
-    
+
     async def get_coin(self, id):
         url = f"{self.base_url}/coins/{id}"
 
-        return await self.rest_client.get(url, limiter=self.limiter)
-        
+        def fn(data, text, response):
+            return None if response.status in [404] else data
+
+        return await self.rest_client.get(url, fn, allowed_response_codes=[200, 404], limiter=self.limiter)
+
     async def get_coins(self):
         url = f"{self.base_url}/coins/list?include_platform=true"
 
         return await self.rest_client.get(url, limiter=self.limiter)
-        
+
     async def get_coin_id_map(self, platform_id):
 
         url = f"{self.base_url}/coins/list?include_platform=true"
@@ -38,7 +41,7 @@ class CoingeckoService:
             map[coin["platforms"][platform_id]] = coin["id"]
 
         return map
-    
+
     async def get_coin_address_map(self, platform_id):
 
         url = f"{self.base_url}/coins/list?include_platform=true"
@@ -54,7 +57,7 @@ class CoingeckoService:
             map[coin["id"]] = coin["platforms"][platform_id]
 
         return map
-    
+
     async def get_historic_price(self, coin_id, date_str, fiat_id):
 
         url = f"{self.base_url}/coins/{coin_id}/history?date={date_str}"
@@ -71,10 +74,10 @@ class CoingeckoService:
 
         return result
 
-    async def get_coin_markets(self, page = 1, per_page = 50, vs_currency = "usd", category = None):
+    async def get_coin_markets(self, page=1, per_page=50, vs_currency="usd", category=None):
 
         url = f"{self.base_url}/coins/markets?vs_currency={vs_currency}&order=market_cap_desc&per_page={per_page}&page={page}&sparkline=false"
-        
+
         if category:
             url += f"&category={category}"
 
